@@ -20,7 +20,7 @@ class Library(object):
     __scenarios = None
     __datasheets = None
     
-    def __init__(self, location, session): # dja make the name more intuitive as well as matching the docstring name and internal consistentcy
+    def __init__(self, location=None, session=None):
         """
         Initializes a pysyncrosim Library instance.
 
@@ -36,9 +36,20 @@ class Library(object):
         None.
 
         """
-        self.__name = os.path.basename(location) # dja Changed to use new parameter name.  Changed to using the os.path function basename as this makes script more understandable and pythonic 
+        self.__location = location
         self.__session = session
-        self.__location = location  # dja needed to match the name change in the class definition
+
+        # Initialize when in a SyncroSim environment
+        if location is None and session is None:
+            e = _environment()
+            if e.program_directory.item() is not None:
+                self.__location = e.library_filepath.item()
+                self.__session = ps.Session(e.program_directory.item())
+            else:
+                raise RuntimeError("Not in a SyncroSim environment." +
+                                   " Please specify a location and session.")
+
+        self.__name = os.path.basename(self.__location)
         self.__addons = self.__init_addons()
         self.__info = None
         self.__package = None
@@ -367,7 +378,7 @@ class Library(object):
         
     def datasheets(self, name=None, summary=True, optional=False, empty=False,
                    scope="Library", filter_column=None, filter_value=None,
-                   include_key=False, return_hidden=False, *ids):
+                   include_key=False, show_full_paths=True, return_hidden=False, *ids):
         """
         Retrieves a DataFrame of Library Datasheets.
 
@@ -392,6 +403,9 @@ class Library(object):
         include_key : Logical, optional
             Whether to include the primary key of the Datasheet, corresponding
             to the SQL database. Default is False.
+        show_full_paths : Logical, optional
+            If set to True, returns the full path of any external files in the 
+            Datasheet. Default is True.
         return_hidden : Logical, optional
             If set to True, returns all records in a Datasheet, including those
             hidden from the user. Results in a slower query. Default is False. 
@@ -414,7 +428,7 @@ class Library(object):
         self.__datasheets = None        
         # TODO: Check if datasheet exists in desired scope
         
-        args = self.__initialize_export_args(scope, ids, empty, include_key)
+        args = self.__initialize_export_args(scope, ids, empty, include_key, show_full_paths)
         
         if name is None:
             
@@ -874,6 +888,9 @@ class Library(object):
         # Retrieves Scenario info from the name or ID
         if name is None and sid is None:
             return None
+        if name is not None and sid is not None:
+            return self.__scenarios[
+                (self.__scenarios["Name"] == name) & (self.__scenarios["ScenarioID"] == sid)]
         if name is not None:
             return self.__scenarios[self.__scenarios["Name"] == name]
         else:
@@ -1260,7 +1277,7 @@ class Library(object):
             raise TypeError("copy_external_inputs must be a Logical")
             
     
-    def __initialize_export_args(self, scope, ids, empty, include_key):
+    def __initialize_export_args(self, scope, ids, empty, include_key, show_full_paths):
     
         args = ["--export", "--lib=%s" % self.__location]
         
@@ -1275,6 +1292,9 @@ class Library(object):
             
         if include_key:
             args += ["--includepk"]
+        
+        if show_full_paths:
+            args += ["--extfilepaths"]
             
         return args
     
@@ -1511,7 +1531,7 @@ class Library(object):
     def __find_scope_id_args(self, input_sheet_name, scope, ids, args):
         
         scope_list = ["Project", "Scenario", "Library"]
-        
+
         if (self.__datasheets.Name == input_sheet_name).any():
             
             input_scope = scope
