@@ -62,6 +62,8 @@ def test_helper():
     
     mySession = ps.Session()
     mySession.add_packages("stsim")
+    mySession.add_packages("stsimsf")
+    mySession.add_packages("stsimcbmcfs3")
     
     # Type checking
     with pytest.raises(
@@ -80,9 +82,12 @@ def test_helper():
     with pytest.raises(TypeError, match="package must be a String"):
         ps.library(name="Test", package=1)
         
-    with pytest.raises(TypeError, match="addons must be a String"):
+    with pytest.raises(TypeError, match="addons must be None, a String, or a List"):
         ps.library(name="Test", addons=1)
-        
+
+    with pytest.raises(TypeError, match="addons in list are not all strings"):
+        ps.library(name="Test", addons=["addon1", 1])
+
     with pytest.raises(TypeError, match="templates must be a String"):
         ps.library(name="Test", template=1)
         
@@ -110,6 +115,30 @@ def test_helper():
     # Test output
     myLibrary = ps.library(name="Test", forceUpdate=True)
     assert isinstance(myLibrary, ps.Library)
+
+    # Test addon packages
+    myLibrary = ps.library(name = "stsimLibrary",
+                       session = mySession,
+                       package = "stsim",
+                       addons = "stsimsf",
+                       overwrite = True)
+    addon_list = myLibrary.addons["Name"].tolist()
+    assert "stsimsf" in addon_list
+    assert "stsimcbmcfs3" in addon_list
+    assert len(addon_list) >= 2
+    assert "No" in myLibrary.addons.Enabled.values
+    assert "Yes" in myLibrary.addons.Enabled.values
+
+    myLibrary = ps.library(name = "stsimLibrary",
+                       session = mySession,
+                       package = "stsim",
+                       addons = ["stsimsf", "stsimcbmcfs3"],
+                       overwrite = True)
+    addon_list = myLibrary.addons["Name"].tolist()
+    assert "stsimsf" in addon_list
+    assert "stsimcbmcfs3" in addon_list
+    addon_enabled_list = np.unique(myLibrary.addons.Enabled.values).tolist()
+    assert "Yes" in addon_enabled_list
     
 def test_library_attributes():
     
@@ -123,6 +152,11 @@ def test_library_attributes():
     assert isinstance(myLibrary.package, str)
     assert isinstance(myLibrary.addons, pd.DataFrame)
 
+    # Check environment error
+    with pytest.raises(RuntimeError,
+            match="Not in a SyncroSim environment."):
+        ps.Library()
+
 def test_library_projects():
     
     myLibrary = ps.library(name="Test", overwrite=True)
@@ -251,7 +285,7 @@ def test_library_datasheets():
     assert isinstance(myLibrary.datasheets(name="core_Backup"), pd.DataFrame)
     assert isinstance(myLibrary.datasheets(summary=False), list)
     assert len(myLibrary.datasheets().columns) == 3
-    assert len(myLibrary.datasheets(optional=True).columns) == 6
+    assert len(myLibrary.datasheets(optional=True).columns) == 7
     assert myLibrary.datasheets(name="core_Backup", empty=True).empty
     assert not myLibrary.datasheets().equals(
         myLibrary.datasheets(scope="Project"))
@@ -396,7 +430,7 @@ def test_library_run():
         myLibrary.run(jobs="1")
     
     runcontrol = myLibrary.datasheets("RunControl", True, False, False,
-                                      "Scenario", None, None, False, False, 1)
+                                      "Scenario", None, None, False, True, False, 1)
     runcontrol["MaximumIteration"] = 2
     runcontrol["MaximumTimestep"] = 2
     myLibrary.save_datasheet("RunControl", runcontrol, 
@@ -517,7 +551,7 @@ def test_project_datasheets():
     assert myProject.datasheets(
         summary='CORE')["Name"].iloc[0].startswith("core")
     assert len(myProject.datasheets().columns) == 3
-    assert len(myProject.datasheets(optional=True).columns) == 6
+    assert len(myProject.datasheets(optional=True).columns) == 7
     assert myProject.datasheets(name="core_Transformer").empty is False
     assert myProject.datasheets(name="core_Transformer", empty=True).empty
     
@@ -646,7 +680,7 @@ def test_scenario_datasheets():
     assert myScenario.datasheets(
         summary='CORE')["Name"].iloc[0].startswith("core")
     assert len(myScenario.datasheets().columns) == 3
-    assert len(myScenario.datasheets(optional=True).columns) == 7
+    assert len(myScenario.datasheets(optional=True).columns) == 8
     assert isinstance(myScenario.datasheets(
         name="RunControl",
         filter_column="MinimumIteration", 
@@ -916,12 +950,26 @@ def test_scenario_copy_dep_delete():
     
     myNewScn.dependencies(dependency=myNewerScn.name)
     assert myNewScn.dependencies().empty is False
+
+    myNewScn.dependencies(dependency=myNewerScn.name) # should not throw error
+
+    with pytest.raises(
+            ValueError,
+            match="Scenario dependency My Scenario 3 does not exist"):
+        myNewScn.dependencies(dependency=[myNewerScn.name, "My Scenario 3"])
     
     sameNameScn = myScenario.copy(name="My Scenario 2")
     with pytest.raises(
             ValueError,
             match="dependency name not unique, use ID or Scenario"):
         myNewScn.dependencies(dependency=sameNameScn.name)
+
+    myNewScn.dependencies(dependency=[myNewerScn, sameNameScn])
+    assert len(myNewScn.dependencies()) == 2
+
+    myNewScn.dependencies(dependency=[myNewerScn.sid, sameNameScn.sid],
+        remove=True, force=True)
+    assert myNewScn.dependencies().empty is True
         
     # Test ignore_dependencies
     with pytest.raises(TypeError, match="value must be a String"):
